@@ -18,7 +18,7 @@ Yahoo::Marketing::BudgetingService - an object that provides operations for sett
 
 See EWS documentation online for available SOAP methods:
 
-L<http://ysm.techportal.searchmarketing.yahoo.com/docs/reference/services/BudgetingService.asp>
+L<http://searchmarketing.yahoo.com/developer/docs/V3/reference/services/BudgetingService.php>
 
 Also see perldoc Yahoo::Marketing::Service for functionality common to all service modules.
 
