@@ -9,12 +9,13 @@ use Test::More;
 
 use Yahoo::Marketing::AdGroupResponse;
 
-sub test_can_create_ad_group_response_and_set_all_fields : Test(4) {
+sub test_can_create_ad_group_response_and_set_all_fields : Test(5) {
 
     my $ad_group_response = Yahoo::Marketing::AdGroupResponse->new
                                                              ->adGroup( 'ad group' )
                                                              ->errors( 'errors' )
                                                              ->operationSucceeded( 'operation succeeded' )
+                                                             ->warnings( 'warnings' )
                    ;
 
     ok( $ad_group_response );
@@ -22,6 +23,7 @@ sub test_can_create_ad_group_response_and_set_all_fields : Test(4) {
     is( $ad_group_response->adGroup, 'ad group', 'can get ad group' );
     is( $ad_group_response->errors, 'errors', 'can get errors' );
     is( $ad_group_response->operationSucceeded, 'operation succeeded', 'can get operation succeeded' );
+    is( $ad_group_response->warnings, 'warnings', 'can get warnings' );
 
 };
 
